.. include:: ../README.rst
    :end-before: _before-intro:

.. toctree::
    :numbered:

    intro
    install
    usage
    contribute
    faq
    code
    CHANGES
    indices

.. include:: ../README.rst
    :start-after: _before-replacements: